==> tuaneda-0.0.1.tar.gz: tuaneda-0.0.1/setup.py <==
from distutils.core import setup


setup(
  name = 'tuaneda',         # How you named your package folder (MyLib)
  packages = ['tuaneda'],   # Chose the same as "name"
  version = '0.0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Quick EDA and important variable analysis',   # Give a short description about your library
  author = 'Tuan Bui',                   # Type in your name
  author_email = 'kevbui.29@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/ubunTuan',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/ubunTuan/tuaneda/archive/0.0.1.tar.gz',    # I explain this later on
  keywords = ['eda', 'important variables', 'exploratory analysis'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
    'seaborn','matplotlib','sklearn','panda',
    'numpy','statsmodels','eli5'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.6'
  ],
)

==> tuaneda-0.0.2.tar.gz: tuaneda-0.0.2/setup.py <==
from distutils.core import setup


setup(
  name = 'tuaneda',         # How you named your package folder (MyLib)
  packages = ['tuaneda'],   # Chose the same as "name"
  version = '0.0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Quick EDA and important variable analysis',   # Give a short description about your library
  author = 'Tuan Bui',                   # Type in your name
  author_email = 'kevbui.29@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/ubunTuan',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/ubunTuan/tuaneda/archive/0.0.2.tar.gz',    # I explain this later on
  keywords = ['eda', 'important variables', 'exploratory analysis'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
    'seaborn','matplotlib','sklearn','panda',
    'numpy','statsmodels','eli5','missingno'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.6'
  ],
)
